mutationtools.ScoreMutationAgent
================================

.. abjad-lineage:: abjad.tools.mutationtools.ScoreMutationAgent.ScoreMutationAgent.ScoreMutationAgent

.. autoclass:: abjad.tools.mutationtools.ScoreMutationAgent.ScoreMutationAgent.ScoreMutationAgent

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.mutationtools.ScoreMutationAgent.ScoreMutationAgent.ScoreMutationAgent.copy
      ~abjad.tools.mutationtools.ScoreMutationAgent.ScoreMutationAgent.ScoreMutationAgent.extract
      ~abjad.tools.mutationtools.ScoreMutationAgent.ScoreMutationAgent.ScoreMutationAgent.fuse
      ~abjad.tools.mutationtools.ScoreMutationAgent.ScoreMutationAgent.ScoreMutationAgent.replace
      ~abjad.tools.mutationtools.ScoreMutationAgent.ScoreMutationAgent.ScoreMutationAgent.respell_with_flats
      ~abjad.tools.mutationtools.ScoreMutationAgent.ScoreMutationAgent.ScoreMutationAgent.respell_with_sharps
      ~abjad.tools.mutationtools.ScoreMutationAgent.ScoreMutationAgent.ScoreMutationAgent.scale
      ~abjad.tools.mutationtools.ScoreMutationAgent.ScoreMutationAgent.ScoreMutationAgent.splice
      ~abjad.tools.mutationtools.ScoreMutationAgent.ScoreMutationAgent.ScoreMutationAgent.split
      ~abjad.tools.mutationtools.ScoreMutationAgent.ScoreMutationAgent.ScoreMutationAgent.swap
      ~abjad.tools.mutationtools.ScoreMutationAgent.ScoreMutationAgent.ScoreMutationAgent.__repr__

Bases
-----

- :py:class:`__builtin__.object <object>`

Methods
-------

.. automethod:: abjad.tools.mutationtools.ScoreMutationAgent.ScoreMutationAgent.ScoreMutationAgent.copy
   :noindex:

.. automethod:: abjad.tools.mutationtools.ScoreMutationAgent.ScoreMutationAgent.ScoreMutationAgent.extract
   :noindex:

.. automethod:: abjad.tools.mutationtools.ScoreMutationAgent.ScoreMutationAgent.ScoreMutationAgent.fuse
   :noindex:

.. automethod:: abjad.tools.mutationtools.ScoreMutationAgent.ScoreMutationAgent.ScoreMutationAgent.replace
   :noindex:

.. automethod:: abjad.tools.mutationtools.ScoreMutationAgent.ScoreMutationAgent.ScoreMutationAgent.respell_with_flats
   :noindex:

.. automethod:: abjad.tools.mutationtools.ScoreMutationAgent.ScoreMutationAgent.ScoreMutationAgent.respell_with_sharps
   :noindex:

.. automethod:: abjad.tools.mutationtools.ScoreMutationAgent.ScoreMutationAgent.ScoreMutationAgent.scale
   :noindex:

.. automethod:: abjad.tools.mutationtools.ScoreMutationAgent.ScoreMutationAgent.ScoreMutationAgent.splice
   :noindex:

.. automethod:: abjad.tools.mutationtools.ScoreMutationAgent.ScoreMutationAgent.ScoreMutationAgent.split
   :noindex:

.. automethod:: abjad.tools.mutationtools.ScoreMutationAgent.ScoreMutationAgent.ScoreMutationAgent.swap
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.mutationtools.ScoreMutationAgent.ScoreMutationAgent.ScoreMutationAgent.__repr__
   :noindex:
